Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2672)

Unified Diff: chrome/browser/profiles/profile.h

Issue 10696176: Move UserScript and related into extensions namespace (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/profiles/profile.h
diff --git a/chrome/browser/profiles/profile.h b/chrome/browser/profiles/profile.h
index a1374bd87236c8afcda5d228efc0fab7d6fe3ac3..a18b9dafc9bb0d3e9a9eded052d93a0fe42fa4cd 100644
--- a/chrome/browser/profiles/profile.h
+++ b/chrome/browser/profiles/profile.h
@@ -32,7 +32,6 @@ class PrefService;
class PromoCounter;
class ProtocolHandlerRegistry;
class TestingProfile;
-class UserScriptMaster;
class VisitedLinkMaster;
class WebDataService;
@@ -53,11 +52,14 @@ class LibCrosServiceLibraryImpl;
class ResetDefaultProxyConfigServiceTask;
}
-
namespace content {
class WebUI;
}
+namespace extensions {
+class UserScriptMaster;
+}
+
namespace fileapi {
class FileSystemContext;
}
@@ -199,11 +201,11 @@ class Profile : public content::BrowserContext {
virtual ExtensionService* GetExtensionService() = 0;
// DEPRECATED. Instead, use ExtensionSystem::user_script_master().
// Retrieves a pointer to the UserScriptMaster associated with this
// profile. The UserScriptMaster is lazily created the first time
// that this method is called.
// TODO(yoz): remove this accessor (bug 104095).
- virtual UserScriptMaster* GetUserScriptMaster() = 0;
+ virtual extensions::UserScriptMaster* GetUserScriptMaster() = 0;
// DEPRECATED. Instead, use ExtensionSystem::process_manager().
// Retrieves a pointer to the ExtensionProcessManager associated with this
@@ -199,11 +201,11 @@ class Profile : public content::BrowserContext {
virtual ExtensionService* GetExtensionService() = 0;
// DEPRECATED. Instead, use ExtensionSystem::user_script_master().
- // Retrieves a pointer to the UserScriptMaster associated with this
- // profile. The UserScriptMaster is lazily created the first time
- // that this method is called.
+ // Retrieves a pointer to the extensions::UserScriptMaster associated with
+ // this profile. The extensions::UserScriptMaster is lazily created the first
+ // time that this method is called.
// TODO(yoz): remove this accessor (bug 104095).

Powered by Google App Engine
This is Rietveld 408576698